@@ -37,13 +37,15 @@ bootdistcens <- function (f, niter=1001)
     if (is.null(f$dots))
         funcmle <- function(iter) {
         mle <- do.call(mledist, list(data=data.frame(left=f$censdata[rnumrow[, iter], ]$left, 
-            right=f$censdata[rnumrow[, iter], ]$right), distr=f$distname, start=start))
+            right=f$censdata[rnumrow[, iter], ]$right), distr=f$distname, start=start, 
+            fix.arg=f$fix.arg))
         return(c(mle$estimate, mle$convergence))
         }
     else
         funcmle <- function(iter) {
         mle <- do.call(mledist, c(list(data=data.frame(left=f$censdata[rnumrow[, iter], ]$left, 
-            right=f$censdata[rnumrow[, iter], ]$right), distr=f$distname, start=start), f$dots))
+            right=f$censdata[rnumrow[, iter], ]$right), distr=f$distname, start=start), 
+            fix.arg=f$fix.arg, f$dots))
         return(c(mle$estimate, mle$convergence))
         }
     resboot <- sapply(1:niter, funcmle)
